==> better_hypixel_chat-0.1.1%2B1.21.9-sources.jar: io/github/viciscat/bhc/AddVanillaFont.java <==
package io.github.viciscat.bhc;

import com.google.common.collect.Lists;
import io.github.viciscat.bhc.mixin.FontManagerAccessor;
import io.github.viciscat.bhc.mixin.MinecraftClientAccessor;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3264;
import net.minecraft.class_3268;
import net.minecraft.class_3294;
import net.minecraft.class_3302;
import net.minecraft.class_377;
import net.minecraft.class_378;
import net.minecraft.class_9243;
import net.minecraft.resource.*;
import java.util.Set;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Executor;

//? if >=1.21.9 {
public class AddVanillaFont implements class_3302 {
//?} else {
/*public class AddVanillaFont implements net.fabricmc.fabric.api.resource.IdentifiableResourceReloadListener {
*///?}

    public static final class_2960 ID = BetterHypixelChatMod.id("vanilla_font");

    //? if <1.21.9 {
    /*@Override
    public Identifier getFabricId() {
        return ID;
    }
    *///?}

    @Override
    //? if >=1.21.9 {
    public CompletableFuture<Void> method_25931(class_11558 store, Executor prepareExecutor, class_4045 synchronizer, Executor applyExecutor) {
    //?} else {
    /*public CompletableFuture<Void> reload(Synchronizer synchronizer, ResourceManager manager, Executor prepareExecutor, Executor applyExecutor) {
    *///?}
        return CompletableFuture.supplyAsync(this::loadVanillaIndex, prepareExecutor)
                .thenCompose(synchronizer::method_18352)
                .thenAcceptAsync(index -> {
                    class_310 mc = class_310.method_1551();
                    MinecraftClientAccessor mcAcc = (MinecraftClientAccessor) mc;
                    FontManagerAccessor fontManager = (FontManagerAccessor) mcAcc.getFontManager();
                    index.comp_2351().forEach((id, fonts) -> {
                        id = id.method_45138("vanilla_");
                        //? if >=1.21.9 {
                        class_377 fontStorage = new class_377(new net.minecraft.class_11642(mc.method_1531(), id));
                        //?} else {
                        /*FontStorage fontStorage = new FontStorage(mc.getTextureManager(), id);
                        *///?}
                        Set<class_9243> filters = FontManagerAccessor.invokeGetActiveFilters(mc.field_1690);
                        filters.remove(class_9243.field_49112);
                        fontStorage.method_2004(Lists.reverse(fonts), filters);
                        fontManager.getFontStorages().put(id, fontStorage);
                    });
                    fontManager.getFonts().addAll(index.comp_1497());
                }, applyExecutor);
    }

    private class_378.class_8536 loadVanillaIndex() {
        class_3268 pack = class_310.method_1551().method_45573();
        class_3294 resourceManager = new class_3294(class_3264.field_14188, "minecraft");
        resourceManager.method_24233(pack);
        MinecraftClientAccessor mc = (MinecraftClientAccessor) class_310.method_1551();
        FontManagerAccessor fontManager = (FontManagerAccessor) mc.getFontManager();
        return fontManager.invokeLoadIndex(resourceManager, Runnable::run).join();
    }

    //? if <1.21.9 {
    /*@Override
    public java.util.Collection<Identifier> getFabricDependencies() {
        return java.util.Collections.singleton(net.fabricmc.fabric.api.resource.ResourceReloadListenerKeys.FONTS);
    }
    *///?}
}

==> better_hypixel_chat-0.2.1%2B1.21.8-sources.jar: io/github/viciscat/bhc/AddVanillaFont.java <==
package io.github.viciscat.bhc;

import com.google.common.collect.Lists;
import io.github.viciscat.bhc.mixin.FontManagerAccessor;
import io.github.viciscat.bhc.mixin.MinecraftClientAccessor;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3264;
import net.minecraft.class_3268;
import net.minecraft.class_3294;
import net.minecraft.class_3300;
import net.minecraft.class_377;
import net.minecraft.class_378;
import net.minecraft.class_9243;
import net.minecraft.resource.*;
import java.util.Set;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Executor;

//? if >=1.21.9 {
/*public class AddVanillaFont implements ResourceReloader {
*///?} else {
public class AddVanillaFont implements net.fabricmc.fabric.api.resource.IdentifiableResourceReloadListener {
//?}

    public static final class_2960 ID = BetterHypixelChatMod.id("vanilla_font");

    //? if <1.21.9 {
    @Override
    public class_2960 getFabricId() {
        return ID;
    }
    //?}

    @Override
    //? if >=1.21.9 {
    /*public CompletableFuture<Void> reload(Store store, Executor prepareExecutor, Synchronizer synchronizer, Executor applyExecutor) {
    *///?} else {
    public CompletableFuture<Void> method_25931(class_4045 synchronizer, class_3300 manager, Executor prepareExecutor, Executor applyExecutor) {
    //?}
        return CompletableFuture.supplyAsync(this::loadVanillaIndex, prepareExecutor)
                .thenCompose(synchronizer::method_18352)
                .thenAcceptAsync(index -> {
                    class_310 mc = class_310.method_1551();
                    MinecraftClientAccessor mcAcc = (MinecraftClientAccessor) mc;
                    FontManagerAccessor fontManager = (FontManagerAccessor) mcAcc.getFontManager();
                    index.comp_2351().forEach((id, fonts) -> {
                        id = id.method_45138("vanilla_");
                        //? if >=1.21.9 {
                        /*FontStorage fontStorage = new FontStorage(new net.minecraft.client.font.GlyphBaker(mc.getTextureManager(), id));
                        *///?} else {
                        class_377 fontStorage = new class_377(mc.method_1531(), id);
                        //?}
                        Set<class_9243> filters = FontManagerAccessor.invokeGetActiveFilters(mc.field_1690);
                        filters.remove(class_9243.field_49112);
                        fontStorage.method_2004(Lists.reverse(fonts), filters);
                        fontManager.getFontStorages().put(id, fontStorage);
                    });
                    fontManager.getFonts().addAll(index.comp_1497());
                }, applyExecutor);
    }

    private class_378.class_8536 loadVanillaIndex() {
        class_3268 pack = class_310.method_1551().method_45573();
        class_3294 resourceManager = new class_3294(class_3264.field_14188, "minecraft");
        resourceManager.method_24233(pack);
        MinecraftClientAccessor mc = (MinecraftClientAccessor) class_310.method_1551();
        FontManagerAccessor fontManager = (FontManagerAccessor) mc.getFontManager();
        return fontManager.invokeLoadIndex(resourceManager, Runnable::run).join();
    }

    //? if <1.21.9 {
    @Override
    public java.util.Collection<class_2960> getFabricDependencies() {
        return java.util.Collections.singleton(net.fabricmc.fabric.api.resource.ResourceReloadListenerKeys.FONTS);
    }
    //?}
}
